==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/SourceStrategyOptionsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SourceStrategyOptionsBuilder extends io.fabric8.openshift.api.model.SourceStrategyOptionsFluentImpl<io.fabric8.openshift.api.model.SourceStrategyOptionsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SourceStrategyOptions,io.fabric8.openshift.api.model.SourceStrategyOptionsBuilder>{
  public SourceStrategyOptionsBuilder() {
    this(false);
  }
  public SourceStrategyOptionsBuilder(java.lang.Boolean validationEnabled) {
    this(new SourceStrategyOptions(), validationEnabled);
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptionsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SourceStrategyOptions(), validationEnabled);
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptionsFluent<?> fluent,io.fabric8.openshift.api.model.SourceStrategyOptions instance) {
    this(fluent, instance, false);
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptionsFluent<?> fluent,io.fabric8.openshift.api.model.SourceStrategyOptions instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withIncremental(instance.getIncremental()); 
    this.validationEnabled = validationEnabled; 
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptions instance) {
    this(instance,false);
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptions instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withIncremental(instance.getIncremental()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SourceStrategyOptionsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SourceStrategyOptions build() {
    SourceStrategyOptions buildable = new SourceStrategyOptions(fluent.getIncremental());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceStrategyOptionsBuilder that = (SourceStrategyOptionsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/SourceStrategyOptionsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SourceStrategyOptionsBuilder extends io.fabric8.openshift.api.model.SourceStrategyOptionsFluentImpl<io.fabric8.openshift.api.model.SourceStrategyOptionsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SourceStrategyOptions,io.fabric8.openshift.api.model.SourceStrategyOptionsBuilder>{
  public SourceStrategyOptionsBuilder() {
    this(false);
  }
  public SourceStrategyOptionsBuilder(java.lang.Boolean validationEnabled) {
    this(new SourceStrategyOptions(), validationEnabled);
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptionsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SourceStrategyOptions(), validationEnabled);
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptionsFluent<?> fluent,io.fabric8.openshift.api.model.SourceStrategyOptions instance) {
    this(fluent, instance, false);
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptionsFluent<?> fluent,io.fabric8.openshift.api.model.SourceStrategyOptions instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withIncremental(instance.getIncremental()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptions instance) {
    this(instance,false);
  }
  public SourceStrategyOptionsBuilder(io.fabric8.openshift.api.model.SourceStrategyOptions instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withIncremental(instance.getIncremental()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SourceStrategyOptionsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SourceStrategyOptions build() {
    SourceStrategyOptions buildable = new SourceStrategyOptions(fluent.getIncremental());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceStrategyOptionsBuilder that = (SourceStrategyOptionsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
